Package: cartography
Title: Thematic Cartography
Version: 3.1.5
Authors@R: c(
      person("Timothée", "Giraud", 
        email = "timothee.giraud@cnrs.fr", role = c("cre","aut"), 
        comment = c(ORCID = "0000-0002-1932-3323")),
      person("Nicolas", "Lambert", 
        email = "nicolas.lambert@cnrs.fr", role = "aut"), 
      person("Diego", "Hernangómez", role = "ctb", comment=c(ORCID="0000-0001-8457-4658")),
      person("Ian", "Fellows", role = "cph", 
        comment = "no overlap algorithm for labels, from wordcloud package"))
Description: Create and integrate maps in your R workflow. This package helps 
    to design cartographic representations such as proportional symbols, 
    choropleth, typology, flows or discontinuities maps. It also offers several 
    features that improve the graphic presentation of maps, for instance, map 
    palettes, layout elements (scale, north arrow, title...), labels or legends. 
    See Giraud and Lambert (2017) <doi:10.1007/978-3-319-57336-6_13>.
License: GPL-3
URL: https://github.com/riatelab/cartography/
BugReports: https://github.com/riatelab/cartography/issues/
LazyData: true
Depends: R (>= 3.5.0)
Imports: classInt, curl, graphics, methods, png, raster, Rcpp, sf, sp,
        stats, utils, grDevices
Suggests: lwgeom, SpatialPosition, knitr, rmarkdown, tinytest, covr
LinkingTo: Rcpp
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-07-23 07:51:54 UTC; tim
Author: Timothée Giraud [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-1932-3323>),
  Nicolas Lambert [aut],
  Diego Hernangómez [ctb] (ORCID:
    <https://orcid.org/0000-0001-8457-4658>),
  Ian Fellows [cph] (no overlap algorithm for labels, from wordcloud
    package)
Maintainer: Timothée Giraud <timothee.giraud@cnrs.fr>
Repository: CRAN
Date/Publication: 2025-07-23 08:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 00:17:56 UTC; unix
Archs: cartography.so.dSYM
