# Generated by roxygen2: do not edit by hand

export(barscale)
export(carto.pal)
export(carto.pal.info)
export(choroLayer)
export(discLayer)
export(display.carto.all)
export(display.carto.pal)
export(dotDensityLayer)
export(getBorders)
export(getBreaks)
export(getFigDim)
export(getGridLayer)
export(getLinkLayer)
export(getOuterBorders)
export(getPencilLayer)
export(getPngLayer)
export(getTiles)
export(ghostLayer)
export(gradLinkLayer)
export(gradLinkTypoLayer)
export(hatchedLayer)
export(labelLayer)
export(layoutLayer)
export(legendBarsSymbols)
export(legendChoro)
export(legendCirclesSymbols)
export(legendGradLines)
export(legendHatched)
export(legendPropLines)
export(legendPropTriangles)
export(legendSquaresSymbols)
export(legendTypo)
export(legendWaffle)
export(north)
export(pngLayer)
export(propLinkLayer)
export(propSymbolsChoroLayer)
export(propSymbolsLayer)
export(propSymbolsTypoLayer)
export(propTrianglesLayer)
export(smoothLayer)
export(tilesLayer)
export(typoLayer)
export(waffleLayer)
export(wordcloudLayer)
import(graphics)
importFrom(Rcpp,evalCpp)
importFrom(grDevices,colorRampPalette)
importFrom(stats,aggregate)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(utils,download.file)
useDynLib(cartography, .registration = TRUE)
