library(sf)
library(sp)
mtq <- st_read(system.file("gpkg/mtq.gpkg", package="cartography"), quiet = TRUE)
plot(st_geometry(mtq))
expect_silent(labelLayer(mtq, txt ="LIBGEO"))
plot(st_geometry(mtq))
expect_silent(labelLayer(mtq, txt ="LIBGEO", overlap = FALSE, halo = TRUE))
plot(st_geometry(mtq))
expect_silent(labelLayer(spdf = as(mtq, "Spatial"), txt ="LIBGEO"))
plot(st_geometry(mtq))
expect_silent(labelLayer(x = as(mtq, "Spatial"), txt ="LIBGEO"))
plot(st_geometry(mtq))
expect_silent(labelLayer(mtq, txt ="LIBGEO", overlap = FALSE, show.lines = TRUE))
expect_silent(labelLayer(mtq[1,], txt ="LIBGEO", overlap = FALSE))
