suppressPackageStartupMessages(library(sf))
library(sp)
mtq <- st_read(system.file("gpkg/mtq.gpkg", package="cartography"), quiet = TRUE)
plot(st_geometry(mtq))
expect_silent(barscale(pos = c(713709.9, 1596117)))
expect_silent(barscale(style = "oldschool"))
expect_silent(barscale(pos = "bottomleft", size = 5))
expect_error(barscale(unit="kmm"))
expect_silent(barscale(unit="m"))
expect_silent(barscale(unit="mi"))
